@@ -1,48 +1,48 @@
 package Kephra::App::EditPanel;
-use strict;
-use warnings;
-
 our $VERSION = '0.10';
 
-# visual settings of the Edit Panel
+use strict;
+use warnings; 
+
+# visual and event settings of the Edit Panel
 
 use Wx qw(
-		wxDEFAULT wxNORMAL wxLIGHT wxBOLD wxSLANT wxITALIC
-		wxSTC_CACHE_PAGE
-		wxSTC_EDGE_LINE wxSTC_EDGE_NONE     wxSTC_WRAP_NONE wxSTC_WRAP_WORD
-		wxSTC_STYLE_DEFAULT wxSTC_STYLE_BRACELIGHT wxSTC_STYLE_BRACEBAD
-);
+	wxDEFAULT wxNORMAL wxLIGHT wxBOLD wxSLANT wxITALIC
+	WXK_RETURN
+	wxSTC_CACHE_PAGE
+	wxSTC_CMD_NEWLINE
+	wxSTC_EDGE_LINE wxSTC_EDGE_NONE     wxSTC_WRAP_NONE wxSTC_WRAP_WORD
+	wxSTC_STYLE_DEFAULT wxSTC_STYLE_BRACELIGHT wxSTC_STYLE_BRACEBAD
+);# EVT_STC_CHARADDED EVT_STC_MODIFIED
 #
 # internal API to config und app pointer
 #
-sub _ref {
-	if (ref $_[0] eq 'Wx::StyledTextCtrl'){ $Kephra::app{editpanel} = $_[0] }
-	else                                  { $Kephra::app{editpanel} }
-}
+my $ref;
+sub _ref     { $ref }
+sub _set_ref { $ref = $_[0] if is($_[0]) }
+sub is       { 1 if ref $_[0] eq 'Wx::StyledTextCtrl'}
 sub _config           { $Kephra::config{editpanel} }
 sub _indicator_config { _config()->{indicator} }
+
+sub new { 
+	my $ep = Wx::StyledTextCtrl->new( Kephra::App::Window::_ref() );
+	$ep->DragAcceptFiles(1) if Wx::wxMSW();
+	return $ep;
+}
+sub gets_focus { Wx::Window::SetFocus( _ref() ) if is( _ref() ) }
 #
 # settings
 #
-sub create {
-	my $ep = Wx::StyledTextCtrl->new( Kephra::App::Window::_ref() );
-	$ep->DragAcceptFiles(1) if Wx::wxMSW();
-	_ref($ep);
-	return $ep;
-}
-
-sub gets_focus { Wx::Window::SetFocus( _ref() ) }
-
 sub apply_settings {
-	my $ep        = _ref() or _create();
+	my $ep        = shift || _ref() || _create();
+	return unless is($ep);
 	my $conf      = _config();
 	my $indicator = _indicator_config();
 	my $color     = \&Kephra::Config::color;
-	$Kephra::temp{edit}{caret}{positions} = ();
 
 	# text visuals: font whitespaces
-	load_font();
-	apply_whitespace_settings();
+	load_font($ep);
+	apply_whitespace_settings($ep);
 	$ep->SetWhitespaceForeground
 		( 1, &$color( $indicator->{whitespace}{color} ) );
 
@@ -56,36 +56,123 @@ sub apply_settings {
 			( 1, &$color( $indicator->{selection}{fore_color} ) );
 	}
 	$ep->SetSelBackground( 1,&$color( $indicator->{selection}{back_color}));
-	apply_EOL_settings();
-	apply_LLI_settings();
-	apply_caret_line_settings();
-	apply_indention_guide_settings();
+	apply_EOL_settings($ep);
+	apply_LLI_settings($ep);
+	apply_caret_line_settings($ep);
+	apply_indention_guide_settings($ep);
 
 	# Margins on left side
-	Kephra::App::EditPanel::Margin::apply_settings();
+	Kephra::App::EditPanel::Margin::apply_settings($ep);
 
 	#misc: scroll width, codepage, wordchars
-	apply_autowrap_settings();
+	apply_autowrap_settings($ep);
 
-	$ep->SetScrollWidth($conf->{scroll_width}) 
+	$ep->SetScrollWidth($conf->{scroll_width})
 		unless $conf->{scroll_width} eq 'auto';
 	#wxSTC_CP_UTF8 Wx::wxUNICODE()
 	$ep->SetCodePage(65001);#
-	set_word_chars();
+	set_word_chars($ep);
+	apply_bracelight_settings();
 
 	# internal
 	$ep->SetLayoutCache(wxSTC_CACHE_PAGE);
 	$ep->SetBufferedDraw(1);
+	$conf->{contextmenu}{visible} eq 'default'
+		? $ep->UsePopUp(1) : $ep->UsePopUp(0);
 
-	apply_bracelight_settings();
 	Kephra::Edit::eval_newline_sub();
+	Kephra::Edit::Bookmark::define_marker($ep);
+	connect_events($ep);
 	Kephra::API::EventTable::add_call ( 'editpanel.focus', 'editpanel', sub { 
 		Wx::Window::SetFocus( $ep ) unless $Kephra::temp{dialog}{active};
 	} ) if $conf->{auto}{focus};
 }
 
+sub connect_events {
+	my $ep = shift || _ref();
+	my $trigger = \&Kephra::API::EventTable::trigger;
+	my $config = _config ;
+
+	# override sci presets
+	Wx::Event::EVT_DROP_FILES       ($ep, \&Kephra::File::add_dropped);
+	Wx::Event::EVT_ENTER_WINDOW     ($ep,  sub {&$trigger('editpanel.focus')} );
+
+	Wx::Event::EVT_MIDDLE_DOWN      ($ep,  sub {
+		my ($ep, $event) = @_;
+		my $nr = Kephra::App::EditPanel::Margin::in_nr( $event->GetX, $ep );
+		$nr == -1 ? $event->Skip
+		          : Kephra::App::EditPanel::Margin::on_middle_click($ep, $event, $nr);
+	});
+	Wx::Event::EVT_RIGHT_DOWN       ($ep,  sub {
+		my ($ep, $event) = @_;
+		my $nr = Kephra::App::EditPanel::Margin::in_nr( $event->GetX, $ep );
+		if ($nr == -1) {
+			my $mconf = $config->{contextmenu};
+			if ($mconf->{visible} eq 'custom'){
+				my $menu_id = Kephra::Document::Data::get_value('text_selected')
+					? $mconf->{ID_selection} : $mconf->{ID_normal};
+				my $menu = Kephra::App::ContextMenu::get($menu_id);
+				$ep->PopupMenu($menu, $event->GetX, $event->GetY) if $menu;
+			} 
+		} else {Kephra::App::EditPanel::Margin::on_right_click($ep, $event, $nr)}
+	});
+	#Wx::EVT_SET_FOCUS		    ($ep, sub {});
+	Wx::Event::EVT_STC_SAVEPOINTREACHED($ep, -1, \&Kephra::File::savepoint_reached);
+	Wx::Event::EVT_STC_SAVEPOINTLEFT($ep, -1, \&Kephra::File::savepoint_left);
+	Wx::Event::EVT_STC_MARGINCLICK  ($ep, -1, \&Kephra::App::EditPanel::Margin::on_left_click);
+	
+	Wx::Event::EVT_STC_CHANGE ($ep, -1, sub {
+		Kephra::Document::Data::attr('edit_pos', $_[0]->GetCurrentPos());
+		&$trigger('document.text.change');
+	});
+
+	Wx::Event::EVT_STC_UPDATEUI ($ep, -1, sub {
+		my ( $ep, $event) = @_;
+		my ( $sel_beg, $sel_end ) = $ep->GetSelection;
+		my $is_sel = $sel_beg != $sel_end;
+		my $was_sel = Kephra::Document::Data::get_value('text_selected');
+		Kephra::Document::Data::set_value('text_selected', $is_sel);
+		&$trigger('document.text.select') if $is_sel xor $was_sel;
+		&$trigger('caret.move');
+	});
+
+	Wx::Event::EVT_KEY_DOWN  ($ep, sub {
+		my ($ep, $event) = @_;
+		#$ep = _ref(); 
+		my $key = $event->GetKeyCode +
+			1000 * ($event->ShiftDown + $event->ControlDown*2 + $event->AltDown*4);
+		# reacting on shortkeys that are defined in the Commanlist
+		return if Kephra::API::CommandList::run_cmd_by_keycode($key);
+		# reacting on Enter
+		if ($key ==  WXK_RETURN) { # Enter
+			if ($config->{auto}{brace}{indention}) {
+				my $pos  = $ep->GetCurrentPos - 1;
+				my $char = $ep->GetCharAt($pos);
+				if      ($char == 123) {
+					Kephra::Edit::Format::blockindent_open($pos) ; return;
+				} elsif ($char == 125) {
+					Kephra::Edit::Format::blockindent_close($pos); return;
+				}
+			}
+			$config->{auto}{indention}
+				? Kephra::Edit::Format::autoindent()
+				: $ep->CmdKeyExecute(wxSTC_CMD_NEWLINE) ;
+		}
+		# scintilla handles the rest of the shortkeys
+		else { $event->Skip }
+		#SCI_SETSELECTIONMODE
+		#($key == 350){use Kephra::Ext::Perl::Syntax; Kephra::Ext::Perl::Syntax::check()};
+	});
+}
+
+sub disconnect_events {
+	my $ep = shift || _ref();
+	Wx::Event::EVT_STC_CHANGE  ($ep, -1, sub {});
+	Wx::Event::EVT_STC_UPDATEUI($ep, -1, sub {});
+}
+
 sub set_word_chars { 
-	my $ep   = _ref();
+	my $ep = shift || _ref();
 	my $conf = _config();
 	if ( $conf->{word_chars} ) {
 		$ep->SetWordChars( $conf->{word_chars} );
@@ -94,18 +181,12 @@ sub set_word_chars {
 	}
 }
 
-sub set_tab_size {
-	my $ep   = _ref();
-	my $size = shift;
-	$ep->SetTabWidth($size);
-	$ep->SetIndent($size);
-	$ep->SetHighlightGuide($size);
-}
 #
 # line wrap
 #
 sub apply_autowrap_settings {
-	_ref()->SetWrapMode( _config()->{line_wrap} );
+	my $ep = shift || _ref();
+	$ep->SetWrapMode( _config()->{line_wrap} );
 	Kephra::API::EventTable::trigger('editpanel.autowrap');
 }
 
@@ -117,29 +198,41 @@ sub switch_autowrap_mode {
 		: wxSTC_WRAP_WORD;
 	apply_autowrap_settings();
 }
-
-
+         ##############
+         # indicators #
+         ##############
 #
 # bracelight
 #
+sub bracelight_visible { _indicator_config()->{bracelight}{visible} }
+sub switch_bracelight {
+	bracelight_visible() ? set_bracelight_off() : set_bracelight_on();
+}
+sub set_bracelight_on {
+	_indicator_config()->{bracelight}{visible} = 1;
+	apply_bracelight_settings()
+}
+sub set_bracelight_off {
+	_indicator_config()->{bracelight}{visible} = 0;
+	apply_bracelight_settings()
+}#{bracelight}{mode} = 'adjacent'|'surround';
 
-sub bracelight_visible{ _indicator_config()->{bracelight}{visible} }
-
-sub apply_bracelight_settings{
+sub apply_bracelight_settings {
+	my $ep = shift || _ref();
 	if (bracelight_visible()){
 		Kephra::API::EventTable::add_call
 			('caret.move', 'bracelight', \&paint_bracelight);
-		paint_bracelight();
+		paint_bracelight($ep);
 	} else {
 		Kephra::API::EventTable::del_call('caret.move', 'bracelight');
-		_ref()->BraceHighlight( -1, -1 );
+		$ep->BraceHighlight( -1, -1 );
 	}
 }
 
 sub paint_bracelight {
-	my $ep       = _ref();
+	my $ep       = shift || _ref();
 	my $pos      = $ep->GetCurrentPos;
-	my $tab_size = $Kephra::document{current}{tab_size};
+	my $tab_size = Kephra::Document::Data::get_attribute('tab_size');
 	my $matchpos = $ep->BraceMatch(--$pos);
 	$matchpos = $ep->BraceMatch(++$pos) if $matchpos == -1;
 
@@ -163,10 +256,6 @@ sub paint_bracelight {
 			and $ep->GetTextRange( $pos, $pos + 1 ) =~ tr/{}()\[\]//;
 	}
 }
-
-         ##############
-         # indicators #
-         ##############
 #
 # indention guide
 #
@@ -174,7 +263,8 @@ sub indention_guide_visible {
 	_indicator_config()->{indent_guide}{visible} 
 }
 sub apply_indention_guide_settings {
-	_ref->SetIndentationGuides( indention_guide_visible() )
+	my $ep = shift || _ref();
+	$ep->SetIndentationGuides( indention_guide_visible() )
 }
 sub switch_indention_guide_visibility {
 	_indicator_config()->{indent_guide}{visible} ^= 1;
@@ -186,8 +276,9 @@ sub switch_indention_guide_visibility {
 sub caret_line_visible {
 	_indicator_config()->{caret_line}{visible} 
 }
-sub apply_caret_line_settings { 
-	_ref()->SetCaretLineVisible( caret_line_visible() ) 
+sub apply_caret_line_settings {
+	my $ep = shift || _ref();
+	$ep->SetCaretLineVisible( caret_line_visible() );
 }
 sub switch_caret_line_visibility {
 	_indicator_config()->{caret_line}{visible} ^= 1;
@@ -200,7 +291,7 @@ sub LLI_visible {
 	_indicator_config()->{right_margin}{style} == wxSTC_EDGE_LINE
 }
 sub apply_LLI_settings {
-	my $ep = _ref();
+	my $ep = shift || _ref();
 	my $config = _indicator_config()->{right_margin};
 	my $color   = \&Kephra::Config::color;
 
@@ -226,7 +317,8 @@ sub switch_EOL_visibility {
 	apply_EOL_settings();
 }
 sub apply_EOL_settings {
-	_ref()->SetViewEOL( EOL_visible() ) 
+	my $ep = shift || _ref();
+	$ep->SetViewEOL( EOL_visible() );
 
 }
 #
@@ -236,7 +328,8 @@ sub whitespace_visible {
 	_indicator_config()->{whitespace}{visible} 
 }
 sub apply_whitespace_settings {
-	_ref()->SetViewWhiteSpace( whitespace_visible() )
+	my $ep = shift || _ref();
+	$ep->SetViewWhiteSpace( whitespace_visible() )
 }
 sub switch_whitespace_visibility {
 	my $v = _indicator_config()->{whitespace}{visible} ^= 1;
@@ -247,7 +340,7 @@ sub switch_whitespace_visibility {
 # font settings
 #
 sub load_font {
-	my $ep = _ref();
+	my $ep = shift || _ref();
 	my ( $fontweight, $fontstyle ) = ( wxNORMAL, wxNORMAL );
 	my $font = _config()->{font};
 	$fontweight = wxLIGHT  if $font->{weight} eq 'light';
@@ -287,12 +380,9 @@ sub change_font {
 
 1;
 
-#Kephra::Dialog::msg_box(undef,$fr,"");
-#use Wx::STC qw(wxSTC_CP_UTF8 wxSTC_CP_UTF16); #wxSTC_CP_UTF8 Wx::wxUNICODE()
+#wxSTC_CP_UTF8 wxSTC_CP_UTF16 Wx::wxUNICODE()
 #wxSTC_WS_INVISIBLE wxSTC_WS_VISIBLEALWAYS
-#$ep->GetSelectionMode;
 #$ep->StyleSetForeground (wxSTC_STYLE_CONTROLCHAR, Wx::Colour->new(0x55, 0x55, 0x55));
 #$ep->StyleSetBackground (wxSTC_STYLE_CONTROLCHAR, Wx::Colour->new(0xff, 0xff, 0xff));
-#$ep->SetScrollWidth($Kephra::config{'editpanel'}{'scroll_width'}); #defaultbreite
 #$ep->CallTipShow(3,"testtooltip\n next line"); #tips
-#$ep->SetSelectionMode(wxSTC_SEL_RECTANGLE); #rect selection
+#$ep->SetSelectionMode(wxSTC_SEL_RECTANGLE); #$ep->GetSelectionMode;
