@@ -1,8 +1,5 @@
 package Kephra::App::Menu;
-use strict;
-use warnings;
-
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =item1 Name
 
@@ -14,39 +11,38 @@ Module Kephra::App::Menu - Menu handling for the main app
 
 =cut
 
-use Wx qw (wxITEM_NORMAL wxITEM_CHECK wxITEM_RADIO wxBITMAP_TYPE_XPM);
-use Wx::Event qw (EVT_MENU EVT_MENU_OPEN EVT_MENU_HIGHLIGHT EVT_SET_FOCUS);
+use strict;
+use warnings;
 
+use Wx qw (wxITEM_CHECK wxITEM_RADIO wxITEM_NORMAL);
+
+my %menu;
 sub _ref {
-	if (ref $_[1] eq 'Wx::Menu') {$Kephra::app{menu}{$_[0]}{ref} = $_[1]}
-	else                         {$Kephra::app{menu}{$_[0]}{ref}}
-}
-sub set_absolete { $Kephra::app{menu}{$_[0]}{absolete} = 1 }
-sub not_absolete { $Kephra::app{menu}{$_[0]}{absolete} = 0 }
-sub is_absolete  { $Kephra::app{menu}{$_[0]}{absolete}     }
-
-sub set_update   {
-    $Kephra::app{menu}{$_[0]}{update} =  $_[1] if ref $_[1] eq 'CODE'
-}
-sub no_update  {
-	delete $Kephra::app{menu}{$_[0]}{update} if exists $Kephra::app{menu}{$_[0]}
+	if    (ref $_[1] eq 'Wx::Menu')  {$menu{$_[0]}{ref} = $_[1]}
+	elsif (exists $menu{$_[0]}{ref}) {$menu{$_[0]}{ref}}
 }
+sub _data        { $menu{$_[0]} if stored($_[0]) }
+sub stored       { 1 if ref $menu{$_[0]} eq 'HASH'}
+sub set_absolete { $menu{$_[0]}{absolete} = 1    }
+sub not_absolete { $menu{$_[0]}{absolete} = 0    }
+sub is_absolete  { $menu{$_[0]}{absolete}        }
+sub set_update   { $menu{$_[0]}{update} =  $_[1] if ref $_[1] eq 'CODE' }
+sub no_update    { delete $menu{$_[0]}{update} if stored($_[0]) }
 
 sub add_onopen_check{
 	return until ref $_[2] eq 'CODE';
-	$Kephra::app{ menu }{ $_[0] }{onopen}{ $_[1] } = $_[2];
+	$menu{ $_[0] }{onopen}{ $_[1] } = $_[2];
 }
 sub del_onopen_check{
 	return until $_[1];
-	delete $Kephra::app{menu}{$_[0]}{onopen}{$_[1]}
-		if exists $Kephra::app{menu}{$_[0]}{onopen}{$_[1]};
+	delete $menu{$_[0]}{onopen}{$_[1]} if exists $menu{$_[0]}{onopen}{$_[1]};
 }
 
 # make menu ready for display
 sub ready {
 	my $id = shift;
-	if (ref $Kephra::app{menu}{$id} eq 'HASH'){
-		my $menu = $Kephra::app{menu}{$id};
+	if ( stored($id) ){
+		my $menu = _data($id);
 		if ($menu->{absolete} and $menu->{update})
 			{ $menu->{absolete} = 0 if $menu->{update}() }
 		if (ref $menu->{onopen} eq 'HASH')
@@ -74,11 +70,11 @@ sub create_dynamic {
 					$item{label}= $template->{name};
 					$item{call} = sub {
 						my $filepath =
-							Kephra::Document::get_file_path() || "<$untitled>";
+							Kephra::Document::Data::get_file_path() || "<$untitled>";
 						my $filename =
-							Kephra::Document::file_name() || "<$untitled>";
+							Kephra::Document::Data::file_name() || "<$untitled>";
 						my $firstname =
-							Kephra::Document::first_name() || "<$untitled>";
+							Kephra::Document::Data::first_name() || "<$untitled>";
 						my $content = $template->{content};
 						$content =~ s/\[\$\$firstname\]/$firstname/g;
 						$content =~ s/\[\$\$filename\]/$filename/g;
@@ -109,7 +105,7 @@ sub create_dynamic {
 				$item{type} = 'item';
 				$item{label}= ( File::Spec->splitpath( $file ) )[2];
 				$item{help}= $file;
-				my $cmd = 'sub {Kephra::Document::Internal::add(\''.$file.'\')}';
+				my $cmd = 'sub {Kephra::Document::add(\''.$file.'\')}';
 				$item{call} = eval $cmd;
 				push @menu_data, \%item; 
 			}
@@ -126,8 +122,8 @@ sub create_dynamic {
 
 		set_update( $menu_id, sub {
 			return unless exists $Kephra::temp{document}{buffer};
-			my $filenames = Kephra::Document::all_file_names();
-			my $pathes = Kephra::Document::all_file_pathes();
+			my $filenames = Kephra::Document::Data::all_file_names();
+			my $pathes = Kephra::Document::Data::all_file_pathes();
 			my $untitled = Kephra::Config::Localisation::strings()->{app}{general}{untitled};
 			my $space = ' ';
 			my @menu_data;
@@ -145,8 +141,8 @@ sub create_dynamic {
 
 		add_onopen_check( $menu_id, 'select', sub {
 			my $menu = _ref($menu_id);
-			my $check_nr = Kephra::Document::current_nr();
-			$menu->FindItemByPosition($check_nr)->Check(1);
+			my $check_nr = Kephra::Document::Data::current_nr();
+			$menu->FindItemByPosition($check_nr)->Check(1) if $menu;
 		});
 
 		set_absolete($menu_id);
@@ -232,11 +228,8 @@ sub eval_data {
 	return unless defined $menu_id;
 	#emty the old or create new menu under the given ID
 	my $menu = _ref($menu_id);
-	if (defined $menu) {
-		$menu->Delete( $_ ) for $menu->GetMenuItems;
-	} else { 
-		$menu = Wx::Menu->new();
-	}
+	if (defined $menu and $menu) { $menu->Delete( $_ ) for $menu->GetMenuItems } 
+	else                         { $menu = Wx::Menu->new() }
 
 	my $menu_data = shift;
 	unless (ref $menu_data eq 'ARRAY') {
@@ -246,10 +239,10 @@ sub eval_data {
 
 	my $win = Kephra::App::Window::_ref();
 	my $kind;
-	my $item_id = exists $Kephra::app{menu}{$menu_id}{item_id}
-		? $Kephra::app{menu}{$menu_id}{item_id}
+	my $item_id = defined $menu{$menu_id}{item_id}
+		? $menu{$menu_id}{item_id}
 		: $Kephra::app{GUI}{masterID}++ * 100;
-	$Kephra::app{menu}{$menu_id}{item_id} = $item_id;
+	$menu{$menu_id}{item_id} = $item_id;
 
 	for my $item_data (@$menu_data){
 		if (not $item_data->{type} or $item_data->{type} eq 'separator'){
@@ -263,7 +256,7 @@ sub eval_data {
 				$menu_item = $menu->Append
 					($item_id++, $item_data->{label}, ready( $item_data->{id} ));
 			}
-			#EVT_MENU_HIGHLIGHT($win, $item_id-1, sub {
+			#Wx::Event::EVT_MENU_HIGHLIGHT($win, $item_id-1, sub {
 				#print " $item_data->{label}- \n";
 			#});
 		} else {
@@ -272,14 +265,14 @@ sub eval_data {
 			} elsif ($item_data->{type} eq 'radioitem'){
 				$kind = wxITEM_RADIO
 			} elsif ($item_data->{type} eq 'item'){
-				$kind = wxITEM_NORMAL 
+				$kind = wxITEM_NORMAL
 			} else { next; }
 
 			my $menu_item = Wx::MenuItem->new
 				($menu, $item_id, $item_data->{label}, '', $kind);
 			if ($item_data->{type} eq 'item') {
 				if (ref $item_data->{icon} eq 'Wx::Bitmap') {
-					$menu_item->SetBitmap( $item_data->{icon} )
+					$menu_item->SetBitmap( $item_data->{icon} ) unless Wx::wxMAC;
 				}
 				else {
 					# insert fake empty icons
@@ -294,8 +287,8 @@ sub eval_data {
 				$menu_item->Check( $item_data->{state}() )
 			} ) if ref $item_data->{state} eq 'CODE';
 
-			EVT_MENU          ($win, $menu_item, $item_data->{call} );
-			EVT_MENU_HIGHLIGHT($win, $menu_item, sub {
+			Wx::Event::EVT_MENU          ($win, $menu_item, $item_data->{call} );
+			Wx::Event::EVT_MENU_HIGHLIGHT($win, $menu_item, sub {
 				Kephra::App::StatusBar::info_msg( $item_data->{help} )
 			});
 			$menu->Append( $menu_item );
@@ -315,7 +308,7 @@ sub destroy {
 	my $menu = _ref( $menu_ID );
 	return unless $menu;
 	$menu->Destroy;
-	Kephra::API::EventTable::del_own_subscription( $menu_ID );
+	Kephra::API::EventTable::del_own_subscriptions( $menu_ID );
 }
 
-1;
+1;
\ No newline at end of file
