@@ -31,10 +31,11 @@ sub main {
 		$Kephra::temp{dialog}{config}{active} = 1;
 		my $frame  = Kephra::App::Window::_ref();
 		my $config = $Kephra::config{dialog}{config};
-		my $d_l10n = $Kephra::localisation{dialog}{config};
-		my $g_l10n = $Kephra::localisation{dialog}{general};
-		my $m_l10n = $Kephra::localisation{app}{menu};
-		my $cl_l10n= $Kephra::localisation{commandlist}{label};
+		my $l18n   = Kephra::Config::Localisation::strings();
+		my $d_l10n = $l18n->{dialog}{config};
+		my $g_l10n = $l18n->{dialog}{general};
+		my $m_l10n = $l18n->{app}{menu};
+		my $cl_l10n = $l18n->{commandlist}{label};
 		my $d_style= wxNO_FULL_REPAINT_ON_RESIZE | wxSYSTEM_MENU | wxCAPTION
 			| wxMINIMIZE_BOX | wxCLOSE_BOX;
 		#$d_style |= wxSTAY_ON_TOP if $Kephra::config{app}{window}{stay_on_top};
