@@ -1,5 +1,5 @@
 package Kephra::Dialog::Info;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use strict;
 use warnings;
@@ -36,12 +36,12 @@ sub simple {
 	elsif ($v eq '2.8.4'){$sciv .= '1.70'}
 	elsif ($v eq '2.8.7'){$sciv .= '1.70'}
 	elsif ($v eq '.8.10'){$sciv .= '1.70'}
-	my $content = "Kephra, Neter of software creation\n"
-		. "$info->{mady_by}  Herbert Breunung\n\n"
-		. "$info->{licensed} GPL (GNU Public License) \n"
+	my $content = "Kephra, $info->{motto}\n"
+		. $info->{mady_by} . "  Herbert Breunung\n\n"
+		. $info->{licensed} . " GPL (GNU Public License) \n"
 		. " ( $info->{detail} \n   $info->{more} ) \n"
 		. "$info->{homepage}  http://kephra.sf.net\n\n"
-		. "$info->{contains}: \n"
+		. $info->{contains} . ": \n"
 		. " - Perl ". substr($],0,1).'.'.int(substr($],3,2)).'.'.substr($],7,1)."\n"
 		. " - WxPerl $Wx::VERSION $info->{wrappes} \n"
 		. "   - " . wxVERSION_STRING . " $info->{and} $sciv\n"
